@@ -2,7 +2,7 @@
                           main.cpp  -  main program
                              -------------------
     begin                : sam déc  1 23:40:19 CET 2001
-    copyright            : (C) 2001-2011 by Éric Bischoff
+    copyright            : (C) 2001-2012 by Éric Bischoff
     email                : ebischoff@nerim.net
  ***************************************************************************/
 
@@ -30,12 +30,12 @@
 static const char
 	*name = I18N_NOOP("KEuroCalc"),
 	*description = I18N_NOOP("Cash converter and calculator"),
-	*copyright = I18N_NOOP("(c) 2001-2011, the KEuroCalc developers"),
+	*copyright = I18N_NOOP("(c) 2001-2012, the KEuroCalc developers"),
 	*text = I18N_NOOP("A program by Éric Bischoff <ebischoff@nerim.net>\n\nThis program is dedicated to humorist Michael Moore, for he\nknows that money does not justify anything...\n\nTime Genie exchange rates courtesy of <a href='http://www.timegenie.com/' title='foreign exchange rates courtesy of Time Genie'>Time Genie</a>\n");
 
 int main(int argc, char *argv[])
 {
-	KAboutData aboutData("keurocalc", "keurocalc", ki18n(name), "1.1.0", ki18n(description),
+	KAboutData aboutData("keurocalc", "keurocalc", ki18n(name), "1.2.0", ki18n(description),
 			     KAboutData::License_GPL, ki18n(copyright), ki18n(text));
 	KCmdLineOptions options;
 
@@ -63,18 +63,18 @@ int main(int argc, char *argv[])
 	if ( splashScreen )
 	{
 		splash->show();
-	}
-
-	a.setTopWidget(keurocalc);
-	keurocalc->show();
-
-	if ( splashScreen )
-	{
-		usleep(600000); // Something less idiotic to propose ?
+		splash->repaint();
+		for (int i = 0; i < 8; i++)
+		{	// Something less idiotic to propose?
+			a.processEvents();
+			usleep(100000);
+		}
 		splash->finish(keurocalc);
 	}
 	delete splash;
 
+	a.setTopWidget(keurocalc);
+	keurocalc->show();
 	keurocalc->repaint();
 	return a.exec();
 }
